# metr\_ds\_util
Common data science utilities, published to PyPi.org
## Modules
### stats
Anything related to statistics.
### plot
Anything related to plotting.
### db
Anything related to database connections. 